@@ -4,7 +4,7 @@ use warnings;
 use Carp qw(carp cluck);
 use Try::Tiny;
 
-our $VERSION = '3.07';
+our $VERSION = '3.10';
 our $DEBUG   = 0;
 
 BEGIN {
@@ -108,12 +108,14 @@ as /cgi-bin/dispatch.cgi:
 
 =head1 DESCRIPTION
 
-This module provides a way (as a mod_perl handler or running under vanilla CGI) to look at
-the path (as returned by L<dispatch_path>) of the incoming request, parse
-off the desired module and its run mode, create an instance of that module and run it.
+This module provides a way (as a mod_perl handler or running under
+vanilla CGI) to look at the path (as returned by L<dispatch_path>) of
+the incoming request, parse off the desired module and its run mode,
+create an instance of that module and run it.
 
-It currently supports both generations of mod_perl (1.x and 2.x). Although, for simplicity,
-all examples involving Apache configuration and mod_perl code will be shown using mod_perl 1.x.
+It currently supports both generations of mod_perl (1.x and
+2.x). Although, for simplicity, all examples involving Apache
+configuration and mod_perl code will be shown using mod_perl 1.x.
 This may change as mp2 usage increases.
 
 It will translate a URI like this (under mod_perl):
@@ -133,8 +135,8 @@ into something that will be functionally similar to this
 
 =head2 dispatch(%args)
 
-This is the primary method used during dispatch. Even under mod_perl, the L<handler>
-method uses this under the hood.
+This is the primary method used during dispatch. Even under mod_perl,
+the L<handler> method uses this under the hood.
 
     #!/usr/bin/perl
     use strict;
@@ -156,29 +158,35 @@ This could be the case if the default page is selected (eg: "/" ).
 
 =item prefix
 
-This option will set the string that will be prepended to the name of the application
-module before it is loaded and created. So to use our previous example request of
+This option will set the string that will be prepended to the name of
+the application module before it is loaded and created. So to use our
+previous example request of
 
     /app/index.cgi/module_name/run_mode
 
-This would by default load and create a module named 'Module::Name'. But let's say that you
-have all of your application specific modules under the 'My' namespace. If you set this option
-to 'My' then it would instead load the 'My::Module::Name' application module instead.
+This would by default load and create a module named
+'Module::Name'. But let's say that you have all of your application
+specific modules under the 'My' namespace. If you set this option to
+'My' then it would instead load the 'My::Module::Name' application
+module instead.
 
 =item args_to_new
 
-This is a hash of arguments that are passed into the C<new()> constructor of the application.
+This is a hash of arguments that are passed into the C<new()>
+constructor of the application.
 
 =item table
 
-In most cases, simply using Dispatch with the C<default> and C<prefix> is enough
-to simplify your application and your URLs, but there are many cases where you want
-more power. Enter the dispatch table. Since this table can be slightly complicated,
-a whole section exists on its use. Please see the L<DISPATCH TABLE> section.
+In most cases, simply using Dispatch with the C<default> and C<prefix>
+is enough to simplify your application and your URLs, but there are
+many cases where you want more power. Enter the dispatch table. Since
+this table can be slightly complicated, a whole section exists on its
+use. Please see the L<DISPATCH TABLE> section.
 
 =item debug
 
-Set to a true value to send debugging output for this module to STDERR. Off by default.
+Set to a true value to send debugging output for this module to
+STDERR. Off by default.
 
 =item error_document
 
@@ -193,7 +201,7 @@ B<A string with error message>
 character will be trimmed from final output.
 
 B<A file with content of error document>
-- if it starts with greater-than sign (C<<>). First character will be excluded
+- if it starts with less-than sign (C<<>). First character will be excluded
 as well. Path of this file should be relative to server DOCUMENT_ROOT.
 
 B<A URI to which the application will be redirected> - if no leading C<"> or
@@ -227,22 +235,26 @@ Examples of using error_document (assume error 404 have been returned):
     # internal redirect to /errors/error404.html
     error_document => '/errors/error%s.html'
 
-    # external redirect to http://host.domain/cgi-bin/errors.cgi?error=404
+    # external redirect to
+    # http://host.domain/cgi-bin/errors.cgi?error=404
     error_document => 'http://host.domain/cgi-bin/errors.cgi?error=%s'
 
 =item auto_rest
 
-This tells Dispatch that you are using REST by default and that you care about which HTTP method
-is being used. Dispatch will append the HTTP method name (upper case by default) to
-the run mode that is determined after finding the appropriate dispatch rule. So a GET request
-that translates into C<MyApp::Module->foo> will become C<MyApp::Module->foo_GET>.
+This tells Dispatch that you are using REST by default and that you
+care about which HTTP method is being used. Dispatch will append the
+HTTP method name (upper case by default) to the run mode that is
+determined after finding the appropriate dispatch rule. So a GET
+request that translates into C<< MyApp::Module->foo >> will become
+C<< MyApp::Module->foo_GET >>.
 
 This can be overridden on a per-rule basis in a custom dispatch table.
 
 =item auto_rest_lc
 
-In combinaion with L<auto_rest> this tells Dispatch that you prefer lower cased HTTP method names.
-So instead of C<foo_POST> and C<foo_GET> you'll have C<foo_post> and C<foo_get>.
+In combinaion with L<auto_rest> this tells Dispatch that you prefer
+lower cased HTTP method names.  So instead of C<foo_POST> and
+C<foo_GET> you'll have C<foo_post> and C<foo_get>.
 
 =back
 
@@ -330,7 +342,8 @@ sub dispatch {
           unless exists($args{error_document});
     }
 
-    %args = map { lc $_ => $args{$_} } keys %args;    # lc for backwards compatability
+    %args = map { lc $_ => $args{$_} } keys %args;    # lc for backwards
+                                                      # compatability
 
     # get the PATH_INFO
     my $path_info = $self->dispatch_path();
@@ -338,7 +351,8 @@ sub dispatch {
     # use the 'default' if we need to
     $path_info = $args{default} || '' if(!$path_info || $path_info eq '/');
 
-    # make sure they all start and end with a '/', to correspond with the RE we'll make
+    # make sure they all start and end with a '/', to correspond with
+    # the RE we'll make
     $path_info = "/$path_info" unless(index($path_info, '/') == 0);
     $path_info = "$path_info/" unless(substr($path_info, -1) eq '/');
 
@@ -390,7 +404,7 @@ sub dispatch {
 
         my $auto_rest =
           defined $named_args->{auto_rest} ? $named_args->{auto_rest} : $args{auto_rest};
-        if($auto_rest) {
+        if($auto_rest && defined $rm && length $rm) {
             my $method_lc =
               defined $named_args->{auto_rest_lc}
               ? $named_args->{auto_rest_lc}
@@ -406,8 +420,7 @@ sub dispatch {
     } catch {
         my $e = $_;
         unless ( ref $e ) {
-            local $@ = $e;
-            $e = Exception::Class->caught();
+            $e = Exception::Class::Base->new($e);
         }
         $output = $self->http_error($e, $args{error_document});
     };
@@ -558,8 +571,9 @@ sub http_error {
 
             unless($output) {
 
-                # TODO: possibly provide more feedback in a way that is XSS safe.
-                # (I'm not sure that passing through the raw ENV variable directly is safe.)
+                # TODO: possibly provide more feedback in a way that
+                # is XSS safe.  (I'm not sure that passing through the
+                # raw ENV variable directly is safe.)
                 # <P>We tried: $ENV{REQUEST_URI}</P></BODY></HTML>";
                 $output = qq(
                 <!DOCTYPE HTML PUBLIC "-//IETF//DTD HTML 2.0//EN">
@@ -630,13 +644,15 @@ sub _parse_path {
             $rule =~ s/$http_method_regex//;
         }
 
-        # make sure they start and end with a '/' to match how PATH_INFO is formatted
+        # make sure they start and end with a '/' to match how
+        # PATH_INFO is formatted
         $rule = "/$rule" unless(index($rule, '/') == 0);
         $rule = "$rule/" if(substr($rule, -1) ne '/');
 
         my @names = ();
 
-        # translate the rule into a regular expression, but remember where the named args are
+        # translate the rule into a regular expression, but remember
+        # where the named args are
         # '/:foo' will become '/([^\/]*)'
         # and
         # '/:bar?' will become '/?([^\/]*)?'
@@ -735,22 +751,25 @@ hash of new()
         PerlSetVar  CGIAPP_DISPATCH_DEFAULT /module_name
     </Location>
 
-The above example would tell apache that any url beginning with /app will be handled by
-CGI::Application::Dispatch. It also sets the prefix used to create the application module
-to 'MyApp' and it tells CGI::Application::Dispatch that it shouldn't set the run mode
-but that it will be determined by the application module as usual (through the query
-string). It also sets a default application module to be used if there is no path.
-So, a url of C</app/module_name> would create an instance of C<MyApp::Module::Name>.
+The above example would tell apache that any url beginning with /app
+will be handled by CGI::Application::Dispatch. It also sets the prefix
+used to create the application module to 'MyApp' and it tells
+CGI::Application::Dispatch that it shouldn't set the run mode but that
+it will be determined by the application module as usual (through the
+query string). It also sets a default application module to be used if
+there is no path.  So, a url of C</app/module_name> would create an
+instance of C<MyApp::Module::Name>.
 
-Using this method will add the C<Apache->request> object to your application's C<PARAMS>
-as 'r'.
+Using this method will add the C<Apache->request> object to your
+application's C<PARAMS> as 'r'.
 
     # inside your app
     my $request = $self->param('r');
 
-If you need more customization than can be accomplished with just L<prefix>
-and L<default>, then it would be best to just subclass CGI::Application::Dispatch
-and override L<dispatch_args> since C<handler()> uses L<dispatch> to do the heavy lifting.
+If you need more customization than can be accomplished with just
+L<prefix> and L<default>, then it would be best to just subclass
+CGI::Application::Dispatch and override L<dispatch_args> since
+C<handler()> uses L<dispatch> to do the heavy lifting.
 
     package MyApp::Dispatch;
     use base 'CGI::Application::Dispatch';
@@ -792,7 +811,7 @@ sub handler : method {
     # setup our args to dispatch()
     my %args;
     my $config_args = $r->dir_config();
-    for my $var qw(DEFAULT PREFIX ERROR_DOCUMENT) {
+    for my $var (qw(DEFAULT PREFIX ERROR_DOCUMENT)) {
         my $dir_var = "CGIAPP_DISPATCH_$var";
         $args{lc($var)} = $config_args->{$dir_var}
           if($config_args->{$dir_var});
@@ -824,8 +843,8 @@ sub handler : method {
 
 =head2 dispatch_args()
 
-Returns a hashref of args that will be passed to L<dispatch>(). It will return the following
-structure by default.
+Returns a hashref of args that will be passed to L<dispatch>(). It
+will return the following structure by default.
 
     {
         prefix      => '',
@@ -836,11 +855,11 @@ structure by default.
         ],
     }
 
-This is the perfect place to override when creating a subclass to provide a richer dispatch
-L<table>.
+This is the perfect place to override when creating a subclass to
+provide a richer dispatch L<table>.
 
-When called, it receives 1 argument, which is a reference to the hash of args passed into
-L<dispatch>.
+When called, it receives 1 argument, which is a reference to the hash
+of args passed into L<dispatch>.
 
 =cut
 
@@ -860,9 +879,10 @@ sub dispatch_args {
 =head2 translate_module_name($input)
 
 This method is used to control how the module name is translated from
-the matching section of the path (see L<"Path Parsing">.
-The main reason that this method exists is so that it can be overridden if it doesn't do
-exactly what you want.
+the matching section of the path (see L<"Path Parsing">).
+The main
+reason that this method exists is so that it can be overridden if it
+doesn't do exactly what you want.
 
 The following transformations are performed on the input:
 
@@ -898,11 +918,12 @@ sub translate_module_name {
 
 =head2 require_module($module_name)
 
-This class method is used internally by CGI::Application::Dispatch to take a module
-name (supplied by L<get_module_name>) and require it in a secure fashion. It
-is provided as a public class method so that if you override other functionality of
-this module, you can still safely require user specified modules. If there are
-any problems requiring the named module, then we will C<croak>.
+This class method is used internally by CGI::Application::Dispatch to
+take a module name (supplied by L<get_module_name>) and require it in
+a secure fashion. It is provided as a public class method so that if
+you override other functionality of this module, you can still safely
+require user specified modules. If there are any problems requiring
+the named module, then we will C<croak>.
 
     CGI::Application::Dispatch->require_module('MyApp::Module::Name');
 
@@ -959,24 +980,26 @@ Sometimes it's easiest to explain with an example, so here you go:
     ]
   );
 
-So first, this call to L<dispatch> sets the L<prefix> and passes a C<TMPL_PATH>
-into L<args_to_new>. Next it sets the L<table>.
+So first, this call to L<dispatch> sets the L<prefix> and passes a
+C<TMPL_PATH> into L<args_to_new>. Next it sets the L<table>.
 
 
 =head2 VOCABULARY
 
 Just so we all understand what we're talking about....
 
-A table is an array where the elements are gouped as pairs (similar to a hash's
-key-value pairs, but as an array to preserve order). The first element of each pair
-is called a C<rule>. The second element in the pair is called the rule's C<arg list>.
-Inside a rule there are slashes C</>. Anything set of characters between slashes
-is called a C<token>.
+A table is an array where the elements are gouped as pairs (similar to
+a hash's key-value pairs, but as an array to preserve order). The
+first element of each pair is called a C<rule>. The second element in
+the pair is called the rule's C<arg list>.  Inside a rule there are
+slashes C</>. Anything set of characters between slashes is called a
+C<token>.
 
 =head2 URL MATCHING
 
-When a URL comes in, Dispatch tries to match it against each rule in the table in
-the order in which the rules are given. The first one to match wins.
+When a URL comes in, Dispatch tries to match it against each rule in
+the table in the order in which the rules are given. The first one to
+match wins.
 
 A rule consists of slashes and tokens. A token can one of the following types:
 
@@ -993,48 +1016,61 @@ C<posts> is a literal token.
 
 =item variable
 
-Any token which begins with a colon (C<:>) is a variable token. These are simply
-wild-card place holders in the rule that will match anything in the URL that isn't
-a slash. These variables can later be referred to by using the C<< $self->param >>
-mechanism. In the rule
+Any token which begins with a colon (C<:>) is a variable token. These
+are simply wild-card place holders in the rule that will match
+anything in the URL that isn't a slash. These variables can later be
+referred to by using the C<< $self->param >> mechanism. In the rule
 
     'posts/:category'
 
-C<:category> is a variable token. If the URL matched this rule, then you could retrieve
-the value of that token from whithin your application like so:
+C<:category> is a variable token. If the URL matched this rule, then
+you could retrieve the value of that token from whithin your
+application like so:
 
     my $category = $self->param('category');
 
-There are some variable tokens which are special. These can be used to further customize
-the dispatching.
+There are some variable tokens which are special. These can be used to
+further customize the dispatching.
 
 =over
 
 =item :app
 
-This is the module name of the application. The value of this token will be sent to the
-L<translate_module_name> method and then prefixed with the L<prefix> if there is one.
+This is the module name of the application. The value of this token
+will be sent to the L<translate_module_name> method and then prefixed
+with the L<prefix> if there is one.
 
 =item :rm
 
-This is the run mode of the application. The value of this token will be the actual name
-of the run mode used.
+This is the run mode of the application. The value of this token will be the
+actual name of the run mode used. The run mode can be optional, as
+noted below. Example:
+
+    /foo/:rm?
+
+If no run mode is found, it will default to using the C<< start_mode() >>, just like
+invoking CGI::Application directly. Both of these URLs would end up dispatching
+to the start mode associated with /foo:
+
+    /foo/
+    /foo
 
 =back
 
 =item optional-variable
 
-Any token which begins with a colon (C<:>) and ends with a question mark (<?>) is considered
-optional. If the rest of the URL matches the rest of the rule, then it doesn't matter whether
-it contains this token or not. It's best to only include optional-variable tokens at the end
-of your rule. In the rule
+Any token which begins with a colon (C<:>) and ends with a question
+mark (<?>) is considered optional. If the rest of the URL matches the
+rest of the rule, then it doesn't matter whether it contains this
+token or not. It's best to only include optional-variable tokens at
+the end of your rule. In the rule
 
     'date/:year/:month?/:day?'
 
 C<:month?> and C<:day?> are optional-variable tokens.
 
-Just like with L<variable> tokens, optional-variable tokens' values can also be retrieved by
-the application, if they existed in the URL.
+Just like with L<variable> tokens, optional-variable tokens' values
+can also be retrieved by the application, if they existed in the URL.
 
     if( defined $self->param('month') ) {
         ...
@@ -1042,22 +1078,23 @@ the application, if they existed in the URL.
 
 =item wildcard
 
-The wildcard token "*" allows for partial matches. The token MUST appear at the end of the
-rule.
+The wildcard token "*" allows for partial matches. The token MUST
+appear at the end of the rule.
 
   'posts/list/*'
 
-By default, the C<dispatch_url_remainder> param is set to the remainder of the URL
-matched by the *. The name of the param can be changed by setting "*" argument in the
-L<ARG LIST>.
+By default, the C<dispatch_url_remainder> param is set to the
+remainder of the URL matched by the *. The name of the param can be
+changed by setting "*" argument in the L<ARG LIST>.
 
   'posts/list/*' => { '*' => 'post_list_filter' }
 
 =item method
 
-You can also dispatch based on HTTP method. This is similar to using L<auto_rest> but
-offers more fine grained control. You include the method (case insensitive) at the end of
-the rule and enclose it in square brackets.
+You can also dispatch based on HTTP method. This is similar to using
+L<auto_rest> but offers more fine grained control. You include the
+method (case insensitive) at the end of the rule and enclose it in
+square brackets.
 
   ':app/news[post]'   => { rm => 'add_news'    },
   ':app/news[get]'    => { rm => 'news'        },
@@ -1065,50 +1102,57 @@ the rule and enclose it in square brackets.
 
 =back
 
-The main reason that we don't use regular expressions for dispatch rules is that regular
-expressions provide no mechanism for named back references, like variable tokens do.
+The main reason that we don't use regular expressions for dispatch
+rules is that regular expressions provide no mechanism for named back
+references, like variable tokens do.
 
 =head2 ARG LIST
 
-Each rule can have an accompanying arg-list. This arg list can contain special arguments
-that override something set higher up in L<dispatch> for this particular URL, or just
-have additional args passed available in C<< $self->param() >>
+Each rule can have an accompanying arg-list. This arg list can contain
+special arguments that override something set higher up in L<dispatch>
+for this particular URL, or just have additional args passed available
+in C<< $self->param() >>
 
-For instance, if you want to override L<prefix> for a specific rule, then you can do so.
+For instance, if you want to override L<prefix> for a specific rule,
+then you can do so.
 
     'admin/:app/:rm' => { prefix => 'MyApp::Admin' },
 
 =head1 Path Parsing
 
-This section will describe how the application module and run mode are determined from
-the path if no L<DISPATCH TABLE> is present, and what options you have to
-customize the process.  The value for the path to be parsed is retrieved from
-the L<dispatch_path> method, which by default uses the C<PATH_INFO> environment
-variable.
+This section will describe how the application module and run mode are
+determined from the path if no L<DISPATCH TABLE> is present, and what
+options you have to customize the process.  The value for the path to
+be parsed is retrieved from the L<dispatch_path> method, which by
+default uses the C<PATH_INFO> environment variable.
 
 =head2 Getting the module name
 
-To get the name of the application module the path is split on backslahes (C</>).
-The second element of the returned list (the first is empty) is used to create the application module. So if we
-have a path of
+To get the name of the application module the path is split on
+backslahes (C</>).  The second element of the returned list (the first
+is empty) is used to create the application module. So if we have a
+path of
 
     /module_name/mode1
 
-then the string 'module_name' is used. This is passed through the L<translate_module_name>
-method. Then if there is a C<prefix> (and there should always be a L<prefix>) it is added
-to the beginning of this new module name with a double colon C<::> separating the two.
+then the string 'module_name' is used. This is passed through the
+L<translate_module_name> method. Then if there is a C<prefix> (and
+there should always be a L<prefix>) it is added to the beginning of
+this new module name with a double colon C<::> separating the two.
 
-If you don't like the exact way that this is done, don't fret you do have a couple of options.
-First, you can specify a L<DISPATCH TABLE> which is much more powerful and flexible (in fact
-this default behavior is actually implemented internally with a dispatch table).
-Or if you want something a little simpler, you can simply subclass and extend the
-L<translate_module_name> method.
+If you don't like the exact way that this is done, don't fret you do
+have a couple of options.  First, you can specify a L<DISPATCH TABLE>
+which is much more powerful and flexible (in fact this default
+behavior is actually implemented internally with a dispatch table).
+Or if you want something a little simpler, you can simply subclass and
+extend the L<translate_module_name> method.
 
 =head2 Getting the run mode
 
-Just like the module name is retrieved from splitting the path on slashes, so is the
-run mode. Only instead of using the second element of the resulting list, we use the third
-as the run mode. So, using the same example, if we have a path of
+Just like the module name is retrieved from splitting the path on
+slashes, so is the run mode. Only instead of using the second element
+of the resulting list, we use the third as the run mode. So, using the
+same example, if we have a path of
 
     /module_name/mode2
 
@@ -1120,11 +1164,12 @@ Then the string 'mode2' is used as the run mode.
 
 =item * CGI query strings
 
-CGI query strings are unaffected by the use of C<PATH_INFO> to obtain the module name and run mode.
-This means that any other modules you use to get access to you query argument (ie, L<CGI>,
-L<Apache::Request>) should not be affected. But, since the run mode may be determined by
-CGI::Application::Dispatch having a query argument named 'rm' will be ignored by your application
-module.
+CGI query strings are unaffected by the use of C<PATH_INFO> to obtain
+the module name and run mode.  This means that any other modules you
+use to get access to you query argument (ie, L<CGI>,
+L<Apache::Request>) should not be affected. But, since the run mode
+may be determined by CGI::Application::Dispatch having a query
+argument named 'rm' will be ignored by your application module.
 
 =back
 
@@ -1134,14 +1179,16 @@ With a dispatch script, you can fairly clean URLS like this:
 
  /cgi-bin/dispatch.cgi/module_name/run_mode
 
-However, including "/cgi-bin/dispatch.cgi" in ever URL doesn't add any value to the URL,
-so it's nice to remove it. This is easily done if you are using the Apache web server with
-C<mod_rewrite> available. Adding the following to a C<.htaccess> file would allow you to
-simply use:
+However, including "/cgi-bin/dispatch.cgi" in ever URL doesn't add any
+value to the URL, so it's nice to remove it. This is easily done if
+you are using the Apache web server with C<mod_rewrite>
+available. Adding the following to a C<.htaccess> file would allow you
+to simply use:
 
  /module_name/run_mode
 
-If you have problems with mod_rewrite, turn on debugging to see exactly what's happening:
+If you have problems with mod_rewrite, turn on debugging to see
+exactly what's happening:
 
  RewriteLog /home/project/logs/alpha-rewrite.log
  RewriteLogLevel 9
@@ -1176,8 +1223,8 @@ Here is a more complex example that dispatches "/", which would otherwise
 be treated as a directory, and also supports multiple developer directories,
 so C</~mark> has its own separate dispatching system beneath it.
 
-Note that order matters here! The Location block for "/" needs to come before the
-user blocks.
+Note that order matters here! The Location block for "/" needs to come
+before the user blocks.
 
   <Location />
     RewriteEngine On
@@ -1202,11 +1249,12 @@ user blocks.
     # Run "/" through the dispatcher
     RewriteRule ^/home/mark/www/$ /~mark/cgi-bin/dispatch.cgi [L,QSA]
 
-     # Otherwise, if an actual file or directory is requested, serve directly
+    # Otherwise, if an actual file or directory is requested,
+    # serve directly
     RewriteCond %{REQUEST_FILENAME} !-f
     RewriteCond %{REQUEST_FILENAME} !-d
 
-     # Otherwise, pass everything through to the dispatcher
+    # Otherwise, pass everything through to the dispatcher
     RewriteRule ^(.*)$ /~mark/cgi-bin/dispatch.cgi/$1 [L,QSA]
 
     # These examples may also be helpful, but are unrelated to dispatching.
@@ -1218,31 +1266,35 @@ user blocks.
 
 =head1 SUBCLASSING
 
-While Dispatch tries to be flexible, it won't be able to do everything that people want. Hopefully
-we've made it flexible enough so that if it doesn't do I<The Right Thing> you can easily subclass
-it.
+While Dispatch tries to be flexible, it won't be able to do everything
+that people want. Hopefully we've made it flexible enough so that if
+it doesn't do I<The Right Thing> you can easily subclass it.
 
 =cut
 
 #=head2 PROTECTED METHODS
 #
-#The following methods are intended to be overridden by subclasses if necessary. They are not
-#part of the public API since end users will never touch them. However, to ensure that your
-#subclass of Dispatch does not break with a new release, they are documented here and are considered
-#to be part of the API and will not be changed without very good reasons.
+#The following methods are intended to be overridden by subclasses if
+#necessary. They are not part of the public API since end users will
+#never touch them. However, to ensure that your subclass of Dispatch
+#does not break with a new release, they are documented here and are
+#considered to be part of the API and will not be changed without very
+#good reasons.
 
 =head1 AUTHOR
 
 Michael Peters <mpeters@plusthree.com>
 
-Thanks to Plus Three, LP (http://www.plusthree.com) for sponsoring my work on this module
+Thanks to Plus Three, LP (http://www.plusthree.com) for sponsoring my
+work on this module
 
 =head1 COMMUNITY
 
-This module is a part of the larger L<CGI::Application> community. If you have questions or
-comments about this module then please join us on the cgiapp mailing list by sending a blank
-message to "cgiapp-subscribe@lists.erlbaum.net". There is also a community wiki located at
-L<http://www.cgi-app.org/>
+This module is a part of the larger L<CGI::Application> community. If
+you have questions or comments about this module then please join us
+on the cgiapp mailing list by sending a blank message to
+"cgiapp-subscribe@lists.erlbaum.net". There is also a community wiki
+located at L<http://www.cgi-app.org/>
 
 =head1 SOURCE CODE REPOSITORY
 
@@ -1281,12 +1333,14 @@ http://code.google.com/p/cgi-app-modules/source/checkout
 
 =head1 SECURITY
 
-Since C::A::Dispatch will dynamically choose which modules to use as the content generators,
-it may give someone the ability to execute random modules on your system if those modules can
-be found in you path. Of course those modules would have to behave like L<CGI::Application> based
-modules, but that still opens up the door more than most want. This should only be a problem
-if you don't use a L<prefix>. By using this option you are only allowing Dispatch to pick from
-a namespace of modules to run.
+Since C::A::Dispatch will dynamically choose which modules to use as
+the content generators, it may give someone the ability to execute
+random modules on your system if those modules can be found in you
+path. Of course those modules would have to behave like
+L<CGI::Application> based modules, but that still opens up the door
+more than most want. This should only be a problem if you don't use a
+L<prefix>. By using this option you are only allowing Dispatch to pick
+from a namespace of modules to run.
 
 =head1 SEE ALSO
 
